.. $Id: downloads.rst 1515 2014-03-11 06:05:15Z jemian $

.. _downloads:

=========
Downloads
=========

:home:  http://specdomain.readthedocs.org

:svn trunk:
    https://subversion.xray.aps.anl.gov/bcdaext/specdomain/trunk/src/specdomain/

:svn source releases:
	
    - https://subversion.xray.aps.anl.gov/bcdaext/specdomain/tags/src/

:PyPI: http://pypi.python.org/sphinxcontrib-specdomain
